faker\_file.providers.augment\_file\_from\_dir package
======================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 20

   faker_file.providers.augment_file_from_dir.augmenters
   faker_file.providers.augment_file_from_dir.extractors

Module contents
---------------

.. automodule:: faker_file.providers.augment_file_from_dir
   :members:
   :undoc-members:
   :show-inheritance:
